# Disseny de sistema electrònic de retrovisors

> **Autors:** Brandon Ventura, Patrick Romero, Joel Coll.

> **Grup 2 Tarda**                                 **Curs: 2023/2024** 

--------

## Objectiu

L'objectiu principal del projecte és el disseny d'un controlador de retrovisors, comprenent aquest des de la concepció de la idea, anàlisi i plantejament del disseny tenint en compte els requeriments funcionals demandats i el seu desenvolupament en circuit imprès, mitjançant el software kicad. A més, en el transcurs del projecte es realitzaran presentacions comentades pel professor per fer un seguiment del projecte, monitoritzant així el rendiment del projecte per avaluar l'evolució i les millores suggerides pel professor. Finalment es faran pressupostos per a la frabricació de la PCB en diferents situacions.

El projecte es divideix:

* Diagrama de Blocs.

* Esquemàtic del circuit.

* Layout de circuit imprès.

* Pressupostos de frabricació.

## Requisits / Especificacions demanats

* Elements en comú amb els altres grups: Regulació de tensió, Microcontrolador, Bus de programació, Bus CAN i2c o SPI, Comunicació USART, Botonera, etc.

* Mecanisme de control de moviment de retrovisors amb 3 motors i finals de carrera
  
  * Control de moviment vertical del mirall 
  
  * Control de moviment horitzontal del mirall
  
  * Control de plegat del retrovisor

* Calefactor del mirall per evitar perdre visibilitat.

* Sensor digital de detecció d’angle mort i llum indicadora.

## Diagrama de Blocs

Diagrama preliminar:

![digramav6](/IMATGES/diagrama_proyecto_einesV6.jpg)

Diagrama definitiu:

![diagramabloquesfinal](/IMATGES/diagramadebloquesfinal.jpg)

Model 3D PCB:

![model3d](/IMATGES/model3d.png)

## Components

| Descripció                        | Referència               | Package       | Datasheet                                                                                                                                                                                                                               | Proveïdor                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | Preu/Unitat | Unitats |
|:---------------------------------:|:------------------------:|:-------------:|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:-----------:|:-------:|
| Microcontrolador                  | PIC32MK0256MCJ048T-I/Y8X | SOIC-48       | [datasheet](https://www.farnell.com/datasheets/3178348.pdf)                                                                                                                                                                             | [Farnell](https://es.farnell.com/microchip/pic32mk0256mcj048t-i-y8x/mcu-32bit-120mhz-tqfp-48/dp/3636080?st=pic32mk0256mcj048)                                                                                                                                                                                                                                                                                                                                                                    | 5,58 €      | 1x      |
| Regulador de tensió               | LM1117                   | SOT-223       | [datasheet](https://www.mouser.es/datasheet/2/308/1/LM1117_D-2315022.pdf)                                                                                                                                                               | [Mouser](https://www.mouser.es/ProductDetail/onsemi/LM1117MPX-33NOPB?qs=DPoM0jnrROUIbzbQHFmeig%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                            | 0,61 €      | 1x      |
| Cristall 8 MHz                    | NX3225GD-8MHZ-STD-CRA-3  | SMD3225-2P    | [datasheet](https://www.mouser.es/datasheet/2/905/c_NX3225GD_STD_CRA_3_e-1317534.pdf)                                                                                                                                                   | [Mouser](https://www.mouser.es/ProductDetail/NDK/NX3225GD-8MHZ-STD-CRA-3?qs=55YtniHzbhDA0fw3anYH2g%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                        | 0,52 €      | 1x      |
| cristall 32.768kHz                | VMK3-9001-32K7680000     | SMD3215-2P    | [datasheet](https://www.mouser.es/datasheet/2/268/VMK3_VMK4-2580709.pdf)                                                                                                                                                                | [Mouser](https://www.mouser.es/ProductDetail/Microchip-Technology/VMK3-9001-32K7680000?qs=W%2FMpXkg%252BdQ5SEMenjYvVdg%3D%3D)                                                                                                                                                                                                                                                                                                                                                                    | 6,05 €      | 1x      |
| Sensor Corrent                    | ACS722LLCTR-05AB-T       | SOIC-8        | [datasheet](https://docs.rs-online.com/17bd/0900766b813b5390.pdf)                                                                                                                                                                       | [Mouser](https://www.mouser.es/ProductDetail/Allegro-MicroSystems/ACS722LLCTR-05AB-T?qs=pUKx8fyJudCx1UVzvqolkw%3D%3D)                                                                                                                                                                                                                                                                                                                                                                            | 3,53 €      | 1x      |
| Sensor de proximitat              | SI1153-AB00-GMR          | DFN-10(2x2)   | [datasheet](https://www.mouser.es/datasheet/2/368/si115x_datasheet-1549645.pdf)                                                                                                                                                         | [Mouser](https://www.mouser.es/ProductDetail/Silicon-Labs/SI1153-AB00-GMR?qs=qSfuJ%2Bfl%2Fd7mp7dfVvPRsQ%3D%3D&utm_id=9882080341&gad_source=1&gclid=CjwKCAjwuJ2xBhA3EiwAMVjkVMk11zZTJwQzpNBq-IwFR0WXnwnrbwmdRbfUCqBoDVjtbDIDbIp-1BoCxNEQAvD_BwE&_gl=1*lx86am*_ga*MjAwMzk1NTM5NS4xNjc4MTE5MzM4*_ga_15W4STQT4T*MTcxMzg2MDg1OC4xNy4wLjE3MTM4NjA4NTkuNTkuMC4w)                                                                                                                                        | 6,05 €      | 1x      |
| Diode de protecció                | S10CJHM3/I               | DO-214AB-2    | [datasheet](https://www.vishay.com/docs/87608/s10cgjkm.pdf)                                                                                                                                                                             | [Mouser](https://www.mouser.es/ProductDetail/Vishay-General-Semiconductor/S10CJHM3-I?qs=Vcr9%2FL0R50ieNORsyjsEpA%3D%3D)                                                                                                                                                                                                                                                                                                                                                                          | 0,69 €      | 1x      |
| NMOS                              | IRF3205                  | TO-220-3      | [datasheet](https://www.mouser.es/datasheet/2/196/Infineon_IRF3205_DataSheet_v01_01_EN-3362740.pdf)                                                                                                                                     | [Mouser](https://www.mouser.es/ProductDetail/Infineon-Technologies/IRF3205PBF?qs=2r01AXMCG3Ng8ivZ6KPoqw%3D%3D&mgh=1&vip=1&utm_id=19103542967&gad_source=1&gclid=Cj0KCQjwn7mwBhCiARIsAGoxjaKKtEZYVuuWJTGQvlE8JVxf2Edfda3sJjlfhaLVV4oMcSoQgZpeOnsaAq68EALw_wcB)                                                                                                                                                                                                                                    | 1,34 €      | 6x      |
| Relé de Automoción                | 1393280-6                | ----          | [datasheet](https://www.farnell.com/datasheets/3449662.pdf)                                                                                                                                                                             | [Farnell](https://es.farnell.com/te-connectivity/v23086c1001a403/rel-automotriz-spdt-12vdc-30a/dp/9659013?st=rele%20automocion)                                                                                                                                                                                                                                                                                                                                                                  | 2,84 €      | 7x      |
| Diode supressió de transitori     | SMBJ18CA                 | SMB(DO-214AA) | [datasheet](https://4donline.ihs.com/images/VipMasterIC/IC/AVXC/AVXC-S-A0013562601/AVXC-S-A0013575056-1.pdf?hkey=6D3A4C79FDBF58556ACFDE234799DDF0)                                                                                      | [Farnell](https://es.farnell.com/avx/smbj18ca/tvs-diode-600w-18v-bidir-do-214aa/dp/2429087?st=diodod)                                                                                                                                                                                                                                                                                                                                                                                            | 0,58 €      | 1x      |
| Driver controlador XY de luna     | DRV8906-Q1               | HTSSOP-24     | [datasheet](https://www.ti.com/lit/ds/symlink/drv8906-q1.pdf?ts=1712660730900&ref_url=https%253A%252F%252Fwww.ti.com%252Fproduct%252FDRV8906-Q1%253FkeyMatch%253DDRV8906-Q1%2526tisearch%253Dsearch-everything%2526usecase%253DGPN-ALT) | [Mouser](https://www.mouser.es/ProductDetail/Texas-Instruments/DRV8906QPWPRQ1?qs=OlC7AqGiEDme0TFEJftIwQ%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                   | 3,01 €      | 1x      |
| Transceiver                       | MAX3051ESA+T             | SOIC-8        | [datasheet](https://www.mouser.es/datasheet/2/609/MAX3051-3128607.pdf)                                                                                                                                                                  | [Mouser](https://www.mouser.es/ProductDetail/Analog-Devices-Maxim-Integrated/MAX3051ESA%2BT?qs=CDqwynd4ZNpR5GfQHcjhqg%3D%3D)                                                                                                                                                                                                                                                                                                                                                                     | 3,40 €      | 1x      |
| Led blau                          | IN-S21AT2B               | 0603          | [datasheet](https://www.mouser.es/datasheet/2/180/IN_S21AT2B_V1_0-2001042.pdf)                                                                                                                                                          | [Mouser](https://www.mouser.es/ProductDetail/Inolux/IN-S21AT2B?qs=stqOd1AaK783h6cfCAfvhA%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                                  | 0,35 €      | 1x      |
| 100nF                             | C1206C104K3HACAUTO       | 1206          | [datasheet](https://www.mouser.es/datasheet/2/447/KEM_C1007_X8R_ULTRA_150C_SMD-3316375.pdf)                                                                                                                                             | [Mouser](https://www.mouser.es/ProductDetail/KEMET/C1206C104K3HACAUTO?qs=MyNHzdoqoQIx5mVnh96zoQ%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                           | 0,40 €      | 14x     |
| 10uF                              | UKT1V100MDD              | THT           | [datasheet](https://www.mouser.es/datasheet/2/293/e_ukt-3082221.pdf)                                                                                                                                                                    | [Mouser](https://www.mouser.es/ProductDetail/Nichicon/UKT1V100MDD?qs=kArNe9LFxXm0pVmVJkLbZQ%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                               | 0,39 €      | 3x      |
| 1uF                               | CGA4J1X8L1H105K125AE     | 0805          | [datasheet](https://product.tdk.com/system/files/dam/doc/product/capacitor/ceramic/mlcc/catalog/mlcc_automotive_soft_en.pdf)                                                                                                            | [Mouser](https://www.mouser.es/ProductDetail/TDK/CGA4J1X8L1H105K125AE?qs=zW32dvEIR3sNqGICW%2F0Hww%3D%3D&utm_id=9882080341&gad_source=1&gclid=CjwKCAjwuJ2xBhA3EiwAMVjkVO3S5y64cGed-PdL5BquV__CY6tMxgBBbhHc6Uo_sWv3F25lU_LhWxoC8HIQAvD_BwE)                                                                                                                                                                                                                                                        | 0,54 €      | 1x      |
| 5,1nF                             | C0603C512G5JACAUTO       | 0603          | [datasheet](https://www.mouser.es/datasheet/2/447/KEM_C1086_U2J-3316409.pdf)                                                                                                                                                            | [Mouser](https://www.mouser.es/ProductDetail/KEMET/C0603C512G5JACAUTO?qs=HXFqYaX1Q2xqawSg6lzOnQ%3D%3D&_gl=1*8eqcs*_ga*NTY5NDA4MTguMTcxMzkxNzM4Nw..*_ga_15W4STQT4T*MTcxMzkxNzM4Ny4xLjAuMTcxMzkxNzM4Ny42MC4wLjA)                                                                                                                                                                                                                                                                                   | 0,39 €      | 1x      |
| 22pF                              | 02013A220GAT2A           | 0201          | [datasheet](https://www.mouser.es/datasheet/2/40/C0GNP0_KGM-3216332.pdf)                                                                                                                                                                | [Mouser](https://www.mouser.es/ProductDetail/KYOCERA-AVX/02013A220GAT2A?qs=8uxLZIVza1t02bPvhkkLOQ%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                         | 0,09 €      | 4x      |
| 4.7uF                             | CM105X5R475M25AT         | 0603          | [datasheet](https://www.mouser.es/datasheet/2/40/CM_Series_e-2835982.pdf)                                                                                                                                                               | [Mouser](https://www.mouser.es/ProductDetail/KYOCERA-AVX/CM105X5R475M25AT?qs=rkhjVJ6%2F3ELaMnvQ4rUsGg%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                     | 0,25 €      | 5x      |
| 120 Ω                             | ERJ-U3RD1200V            | 0603          | [datasheet](https://www.mouser.es/datasheet/2/315/RDP0000C343-1855597.pdf)                                                                                                                                                              | [Mouser](https://www.mouser.es/ProductDetail/Panasonic/ERJ-U3RD1200V?qs=TiOZkKH1s2S3tyk7ZYtCFg%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                            | 0,16 €      | 2x      |
| 5.1 kΩ                            | KTR03EZPF5101            | 0603          | [datasheet](https://www.mouser.es/datasheet/2/348/ROHM_S_A0011075115_1-2563276.pdf)                                                                                                                                                     | [Mouser](https://www.mouser.es/ProductDetail/ROHM-Semiconductor/KTR03EZPF5101?qs=493kPxzlxfJaEMp19nnwNA%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                   | 0,15 €      | 3x      |
| 180 Ω                             | MCWR06X1800FTL           | 0603          | [datasheet]()                                                                                                                                                                                                                           | [Farnell](https://es.farnell.com/multicomp/mcwr06x1800ftl/res-180r-1-0-1w-pel-c-gruesa/dp/2447267)                                                                                                                                                                                                                                                                                                                                                                                               | 0,01 €      | 1x      |
| 10 Ω                              | RC0603JR-1010RL          | 0603          | [datasheet](https://www.mouser.es/datasheet/2/447/PYu_RC_Group_51_RoHS_L_11-1984063.pdf)                                                                                                                                                | [Mouser](https://www.mouser.es/ProductDetail/YAGEO/RC0603JR-1010RL?qs=IuGqVx9wL0IBupmB2yCEig%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                              | 0,09 €      | 1x      |
| 10 kΩ                             | HV731JRTTD1002F          | 0603          | [datasheet](https://www.koaspeer.com/products/resistors/high-voltage/hv73-rt/)                                                                                                                                                          | [Mouser](https://www.mouser.es/ProductDetail/KOA-Speer/HV731JRTTD1002F?qs=T%2BzbugeAwjgpffPMFAl3zQ%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                        | 0,67 €      | 8x      |
| 47 kΩ                             | CRCW060347K0FKED         | 0603          | [datasheet](https://www.vishay.com/docs/20035/dcrcwe3.pdf)                                                                                                                                                                              | [Mouser](https://www.mouser.es/ProductDetail/Vishay-Dale/CRCW060347K0FKED?qs=TiOZkKH1s2SEb881Da2bMg%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                       | 0,09 €      | 3x      |
| 1 KΩ                              | CRCW06031K00FKEA         | 0603          | [datasheet](https://www.vishay.com/docs/20035/dcrcwe3.pdf)                                                                                                                                                                              | [Mouser](https://www.mouser.es/ProductDetail/Vishay-Dale/CRCW06031K00FKEA?qs=CToX950LohJasujQx7GY3g%3D%3D)                                                                                                                                                                                                                                                                                                                                                                                       | 0,09 €      | 1x      |
| DB9 Femella                       | 2311765-2                | ---           | [datasheet](https://www.mouser.es/datasheet/2/418/7/ENG_CD_2311765_D-2072969.pdf)                                                                                                                                                       | [Mouser](https://www.mouser.es/ProductDetail/TE-Connectivity/2311765-2?qs=rrS6PyfT74frdzrH7SJRfg%3D%3D&mgh=1&vip=1&utm_id=19103542967&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXt0r6XHcXVAKDy0fb1AQDEcRaa8CqE_BUjWUK4OHCnLL84KZ4c8u68xoCDQcQAvD_BwE)                                                                                                                                                                                                                                            | 2,20 €      | 2x      |
| connector screw                   | 1729128                  | ---           | [datasheet](https://www.phoenixcontact.com/en-us/products/printed-circuit-board-terminal-mkdsn-15-2-508-1729128?type=pdf)                                                                                                               | [Mouser](https://www.mouser.es/ProductDetail/Phoenix-Contact/1729128?qs=GFUSqQMLmmnCBVBY3dts9w%3D%3D&mgh=1&vip=1&utm_id=19103542967&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXt8KX9a8NNp7H64bRl4Mw7KWml4ZEko_NgzJPKvPN3B3hbMd4qNaAhBoC0noQAvD_BwE)                                                                                                                                                                                                                                              | 1,00 €      | 5x      |
| Ferrita                           | 28C0236-0JW-10           | ---           | [datasheet](https://www.mouser.es/datasheet/2/987/Laird_10092020_Laird_MCP_Catalog_EMI_Filtering_and-1947796.pdf)                                                                                                                       | [Mouser](https://www.mouser.es/ProductDetail/Laird-Performance-Materials/28C0236-0JW-10?qs=wjes1ZhMGKc2BBahb2yqoA%3D%3D)                                                                                                                                                                                                                                                                                                                                                                         | 0,87 €      | 2x      |
| Pin Header 1x3 (Final de carrera) | 61300311121              | ---           | [datasheet](https://www.we-online.com/components/products/datasheet/61300311121.pdf)                                                                                                                                                    | [DigiKey](https://www.digikey.es/es/products/detail/w%C3%BCrth-elektronik/61300311121/4846825?utm_adgroup=&utm_source=google&utm_medium=cpc&utm_campaign=PMax_Supplier_W%C3%BCrth%20Elektronik&utm_term=&utm_content=&utm_id=go_cmp-20673490314_adg-_ad-__dev-c_ext-_prd-4846825_sig-CjwKCAjw26KxBhBDEiwAu6KXt-nrzPnR6AizAc4OFYg5FhEvs2IVS_BrHZ7kmUmR4I-WiUOawUIyVxoCUwUQAvD_BwE&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXt-nrzPnR6AizAc4OFYg5FhEvs2IVS_BrHZ7kmUmR4I-WiUOawUIyVxoCUwUQAvD_BwE) | 0,12 €      | 2x      |
| Pin Header 1x6(ICSP)              | 61300611121              | ---           | [datasheet](https://www.we-online.com/components/products/datasheet/61300611121.pdf)                                                                                                                                                    | [DigiKey](https://www.digikey.es/es/products/detail/w%C3%BCrth-elektronik/61300611121/4846833?utm_adgroup=&utm_source=google&utm_medium=cpc&utm_campaign=PMax_Supplier_W%C3%BCrth%20Elektronik&utm_term=&utm_content=&utm_id=go_cmp-20673490314_adg-_ad-__dev-c_ext-_prd-4846833_sig-CjwKCAjw26KxBhBDEiwAu6KXt_VJb-Q9YOu1fwzJgzcGiYhWySUOWYRWv0WGVG9YX4FjvSPAQhZx5RoCu2IQAvD_BwE&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXt_VJb-Q9YOu1fwzJgzcGiYhWySUOWYRWv0WGVG9YX4FjvSPAQhZx5RoCu2IQAvD_BwE) | 0,32 €      | 1x      |
| pin Header 1x2 (Led angle mort)   | 61300211121              | ---           | [datasheet](https://www.we-online.com/components/products/datasheet/61300211121.pdf)                                                                                                                                                    | [DigiKey](https://www.digikey.es/es/products/detail/w%C3%BCrth-elektronik/61300211121/4846823?utm_adgroup=&utm_source=google&utm_medium=cpc&utm_campaign=PMax_Supplier_W%C3%BCrth%20Elektronik&utm_term=&utm_content=&utm_id=go_cmp-20673490314_adg-_ad-__dev-c_ext-_prd-4846823_sig-CjwKCAjw26KxBhBDEiwAu6KXtw-1ZUKYYU8Cupm5Gn3H8J-Xiq9WdqS9z9SH1hMJNHucrmR2xq0LLxoCMhAQAvD_BwE&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXtw-1ZUKYYU8Cupm5Gn3H8J-Xiq9WdqS9z9SH1hMJNHucrmR2xq0LLxoCMhAQAvD_BwE) | 0,12 €      | 1x      |
| Pin Header 1x9 (Botonera)         | PH1-09-UA                | ---           | [datasheet](https://app.adam-tech.com/products/download/data_sheet/201605/ph1-xx-ua-data-sheet.pdf)                                                                                                                                     | [DigiKey](https://www.digikey.es/es/products/detail/adam-tech/PH1-09-UA/9830689?utm_adgroup=&utm_source=google&utm_medium=cpc&utm_campaign=PMax_Product_All%20Products&utm_term=&productid=9830689&utm_content=&utm_id=go_cmp-20199915072_adg-_ad-__dev-c_ext-_prd-9830689_sig-CjwKCAjw26KxBhBDEiwAu6KXt0u3XXGhT9d64uWFShrc_WVyAM-8ELpbID3-wkI9a1cGarWc9QdWsxoCFqQQAvD_BwE&gad_source=1&gclid=CjwKCAjw26KxBhBDEiwAu6KXt0u3XXGhT9d64uWFShrc_WVyAM-8ELpbID3-wkI9a1cGarWc9QdWsxoCFqQQAvD_BwE)       | 0,16 €      | 1x      |

## Motors i finals de carrera

Els controls de control de lluna i plegat/desplegat no entren al pressupost, pero s'utilitzan com a referència pel disseny i construcció dels drivers de motors. A més els finals de carrera no aniràn a la PCB, per tant tampoc es tenen en compte per a el pressupost.

| Servomotor       | Servomotor McLennan Servo Supplies | [datasheet](https://docs.rs-online.com/87fa/0900766b8002f9c4.pdf) | [Rs](https://es.rs-online.com/web/p/servomotores/4329765)                   | 84,03 € | 2x  |
|:----------------:|:----------------------------------:|:-----------------------------------------------------------------:|:---------------------------------------------------------------------------:|:-------:|:---:|
| Motor DC         | Motor DC RS PRO                    | [datasheet](https://docs.rs-online.com/6e47/A700000007082069.pdf) | [Rs](https://es.rs-online.com/web/p/motores-dc/3213186)                     | 40,08 € | 1x  |
| Final de carrera | Palanca de Rodillo RS PRO          | [datasheet](https://docs.rs-online.com/ad80/A700000008919430.pdf) | [Rs](https://es.rs-online.com/web/p/interruptores-final-de-carrera/9026856) | 23,21 € | 1x  |

## Historial de canvis

| Data       | Autor     | Branch   | Versió         | Descripció                                              |
| ---------- | --------- | -------- | -------------- | ------------------------------------------------------- |
| 31/03/2024 | B.Ventura | Master   | initial commit | Primera versió de diagrama de blocs                     |
| 04/03/2024 | P.Romero  | Projecte | V1             | Segona versió diagrama de blocs i elecció de components |
| 04/03/2024 | B.Ventura | Projecte | V1             | Esquemàtic                                              |
| 09/04/2024 | B.Ventura | Projecte | V2             | Modificació del esquemàtic                              |
| 09/04/2024 | P.Romero  | Projecte | V2             | Primera versió de layout                                |
| 18/04/2024 | P.Romero  | projecte | V2             | Modificació de layout                                   |
| 22/04/2024 | B,Ventura | projecte | V3             | Layout i esquemàtic amb els canvis suggerits            |
| 23/04/2024 | B.Ventura | projecte | V4             | Millora de Layout                                       |
| 23/04/2024 | P.Romero  | projecte | V4             | Millora de l'esquemàtic                                 |